# Work left to do:

- [x] Fix the module output
- [ ] Run a test with remote tracking to see that the backend as well as artifact trackers are working.
- [ ] Create s3 module from [Anton Babenko repo](https://registry.terraform.io/modules/terraform-aws-modules/s3-bucket/aws/latest)
- [ ] Create DB subnet in vpc only when remote_tracking is enabled
- [x] Add rds port 5432 to SG only when remote_tracking is enabled
- [ ] Pass variable values from the yaml file
- [x] Update yaml config
